@@ -16,6 +16,21 @@ public:
     void setupShortcuts();
 
 public:
+    QAction *actionOpen;
+
+    QAction *actionActualSize;
+    QAction *actionToggleMaximize;
+    QAction *actionZoomIn;
+    QAction *actionZoomOut;
+    QAction *actionToggleCheckerboard;
+    QAction *actionRotateClockwise;
+
+    QAction *actionPrevPicture;
+    QAction *actionNextPicture;
+
+    QAction *actionHorizontalFlip;
+    QAction *actionFitInView;
+    QAction *actionFitByWidth;
     QAction *actionCopyPixmap;
     QAction *actionCopyFilePath;
     QAction *actionPaste;
