@@ -1,6 +1,8 @@
 #ifndef BOTTOMBUTTONGROUP_H
 #define BOTTOMBUTTONGROUP_H
 
+#include <vector>
+
 #include <QAbstractButton>
 #include <QGroupBox>
 
@@ -9,19 +11,11 @@ class BottomButtonGroup : public QGroupBox
 {
     Q_OBJECT
 public:
-    explicit BottomButtonGroup(QWidget *parent = nullptr);
+    explicit BottomButtonGroup(const std::vector<QAction *> & actionList, QWidget *parent = nullptr);
 
     void setOpacity(qreal opacity, bool animated = true);
     void addButton(QAbstractButton *button);
 
-signals:
-    void resetToOriginalBtnClicked();
-    void toggleWindowMaximum();
-    void zoomInBtnClicked();
-    void zoomOutBtnClicked();
-    void toggleCheckerboardBtnClicked();
-    void rotateRightBtnClicked();
-
 private:
     OpacityHelper * m_opacityHelper;
 };
