@@ -10,6 +10,38 @@
 #include <QLabel>
 #include <QPainter>
 
+class PGraphicsPixmapItem : public QGraphicsPixmapItem
+{
+public:
+    PGraphicsPixmapItem(const QPixmap &pixmap, QGraphicsItem *parent = nullptr)
+        : QGraphicsPixmapItem(pixmap, parent)
+    {}
+
+    void setScaleHint(float scaleHint) {
+        m_scaleHint = scaleHint;
+    }
+
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
+               QWidget *widget) override
+    {
+        if (transformationMode() == Qt::FastTransformation) {
+            return QGraphicsPixmapItem::paint(painter, option, widget);
+        } else {
+//            painter->setRenderHints(QPainter::Antialiasing);
+            QSizeF resizedScale(boundingRect().size());
+            resizedScale *= m_scaleHint;
+            painter->drawPixmap(QRectF(offset(), boundingRect().size()).toRect(),
+                                pixmap().scaled(resizedScale.toSize(),
+                                                Qt::KeepAspectRatio,
+                                                Qt::SmoothTransformation)
+                                );
+        }
+    }
+
+private:
+    float m_scaleHint = 1;
+};
+
 GraphicsScene::GraphicsScene(QObject *parent)
     : QGraphicsScene(parent)
 {
@@ -24,7 +56,8 @@ GraphicsScene::~GraphicsScene()
 void GraphicsScene::showImage(const QPixmap &pixmap)
 {
     this->clear();
-    QGraphicsPixmapItem * pixmapItem = this->addPixmap(pixmap);
+    PGraphicsPixmapItem * pixmapItem = new PGraphicsPixmapItem(pixmap);
+    this->addItem(pixmapItem);
     pixmapItem->setShapeMode(QGraphicsPixmapItem::BoundingRectShape);
     m_theThing = pixmapItem;
     this->setSceneRect(m_theThing->boundingRect());
@@ -48,11 +81,11 @@ void GraphicsScene::showSvg(const QString &filepath)
     this->setSceneRect(m_theThing->boundingRect());
 }
 
-void GraphicsScene::showGif(const QString &filepath)
+void GraphicsScene::showAnimated(const QString &filepath)
 {
     this->clear();
-    QMovie * movie = new QMovie(filepath);
     QLabel * label = new QLabel;
+    QMovie * movie = new QMovie(filepath, QByteArray(), label);
     label->setStyleSheet("background-color:rgba(225,255,255,0);");
     label->setMovie(movie);
     this->addWidget(label);
@@ -62,11 +95,12 @@ void GraphicsScene::showGif(const QString &filepath)
     this->setSceneRect(m_theThing->boundingRect());
 }
 
-bool GraphicsScene::trySetTransformationMode(Qt::TransformationMode mode)
+bool GraphicsScene::trySetTransformationMode(Qt::TransformationMode mode, float scaleHint)
 {
-    QGraphicsPixmapItem * pixmapItem = qgraphicsitem_cast<QGraphicsPixmapItem *>(m_theThing);
+    PGraphicsPixmapItem * pixmapItem = qgraphicsitem_cast<PGraphicsPixmapItem *>(m_theThing);
     if (pixmapItem) {
         pixmapItem->setTransformationMode(mode);
+        pixmapItem->setScaleHint(scaleHint);
         return true;
     }
 
@@ -75,6 +109,11 @@ bool GraphicsScene::trySetTransformationMode(Qt::TransformationMode mode)
 
 QPixmap GraphicsScene::renderToPixmap()
 {
+    PGraphicsPixmapItem * pixmapItem = qgraphicsitem_cast<PGraphicsPixmapItem *>(m_theThing);
+    if (pixmapItem) {
+        return pixmapItem->pixmap();
+    }
+
     QPixmap pixmap(sceneRect().toRect().size());
     pixmap.fill(Qt::transparent);
     QPainter p(&pixmap);
