@@ -11,13 +11,13 @@ class GraphicsView : public QGraphicsView
 public:
     GraphicsView(QWidget *parent = nullptr);
 
-    void showFileFromUrl(const QUrl &url, bool requestGallery = false);
+    void showFileFromPath(const QString &filePath, bool requestGallery = false);
 
     void showImage(const QPixmap &pixmap);
     void showImage(const QImage &image);
     void showText(const QString &text);
     void showSvg(const QString &filepath);
-    void showGif(const QString &filepath);
+    void showAnimated(const QString &filepath);
 
     GraphicsScene * scene() const;
     void setScene(GraphicsScene *scene);
@@ -26,19 +26,25 @@ public:
 
     void resetTransform();
     void zoomView(qreal scaleFactor);
+    void rotateView(bool clockwise = true);
+    void flipView(bool horizontal = true);
     void resetScale();
-    void rotateView(qreal rotateAngel);
     void fitInView(const QRectF &rect, Qt::AspectRatioMode aspectRadioMode = Qt::IgnoreAspectRatio);
+    void fitByOrientation(Qt::Orientation ori = Qt::Horizontal, bool scaleDownOnly = false);
 
-    void checkAndDoFitInView(bool markItOnAnyway = true);
+    void displayScene();
+    bool isSceneBiggerThanView() const;
+    void setEnableAutoFitInView(bool enable = true);
+
+    static QTransform resetScale(const QTransform & orig);
 
 signals:
-    void navigatorViewRequired(bool required, qreal angle);
+    void navigatorViewRequired(bool required, QTransform transform);
     void viewportRectChanged();
     void requestGallery(const QString &filePath);
 
 public slots:
-    void toggleCheckerboard();
+    void toggleCheckerboard(bool invertCheckerboardColor = false);
 
 private:
     void mousePressEvent(QMouseEvent * event) override;
@@ -53,14 +59,15 @@ private:
 
     bool isThingSmallerThanWindowWith(const QTransform &transform) const;
     bool shouldIgnoreMousePressMoveEvent(const QMouseEvent *event) const;
-    void setCheckerboardEnabled(bool enabled);
+    void setCheckerboardEnabled(bool enabled, bool invertColor = false);
     void applyTransformationModeByScaleFactor();
 
-    void resetWithScaleAndRotate(qreal scaleFactor, qreal rotateAngle);
-
+    // Consider switch to 3 state for "no fit", "always fit" and "fit when view is smaller"?
+    // ... or even more? e.g. "fit/snap width" things...
+    // Currently it's "no fit" when it's false and "fit when view is smaller" when it's true.
     bool m_enableFitInView = false;
     bool m_checkerboardEnabled = false;
-    qreal m_rotateAngle = 0;
+    bool m_isLastCheckerboardColorInverted = false;
 };
 
 #endif // GRAPHICSVIEW_H
