@@ -1,4 +1,7 @@
 #include "mainwindow.h"
+
+#include "playlistmanager.h"
+
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDir>
@@ -34,18 +37,12 @@ int main(int argc, char *argv[])
 
     parser.process(a);
 
-    QStringList urlStrList = parser.positionalArguments();
-    QList<QUrl> urlList;
-    for (const QString & str : qAsConst(urlStrList)) {
-        QUrl url = QUrl::fromLocalFile(str);
-        if (url.isValid()) {
-            urlList.append(url);
-        }
-    }
-
     MainWindow w;
     w.show();
 
+    QStringList urlStrList = parser.positionalArguments();
+    QList<QUrl> && urlList = PlaylistManager::convertToUrlList(urlStrList);
+
     if (!urlList.isEmpty()) {
         w.showUrls(urlList);
         w.adjustWindowSizeBySceneRect();
